C     User-defined subroutine for ideal dielectric elastomer film
C       to be used in Abaqus
C	with Gent's model for the energy of stretching
C =================================================================
C       Material constants:
C           Mechanical - PROPS(1:3): mu, epsilon, Jm
C       Temperature is used as the nominal electric field
C         always applied in the Z-direction before deformation
C -----------------------------------------------------------------
C     4/19/2011, Wei Hong. whong@iastate.edu  All rights reserved
C     2014年7月27日       modified by Guoyong Mao
C -----------------------------------------------------------------
      SUBROUTINE UANISOHYPER_INV (AINV, UA, ZETA, NFIBERS, NINV,
     1     UI1, UI2, UI3, TEMP, NOEL, CMNAME, INCMPFLAG, IHYBFLAG,
     2     NUMSTATEV, STATEV, NUMFIELDV, FIELDV, FIELDVINC,
     3     NUMPROPS, PROPS)
C
	     INCLUDE 'ABA_PARAM.INC' 
C
      CHARACTER*80 CMNAME
      DIMENSION AINV(NINV), UA(2), 
     2     ZETA(NFIBERS*(NFIBERS-1)/2), UI1(NINV),
     3     UI2(NINV*(NINV+1)/2), UI3(NINV*(NINV+1)/2),
     4     STATEV(NUMSTATEV), FIELDV(NUMFIELDV),
     5     FIELDVINC(NUMFIELDV), PROPS(NUMPROPS)
      REAL*8 mu,eps,Jm,EE
      
      mu = PROPS(1)         ! Initial shear modulus
      eps = PROPS(3)        ! Permitivity
      Jm = PROPS(2)	    ! Extension limit
      EE = eps*TEMP**2
      eps = 1-(AINV(1)-3)/Jm	! Temporary variable

      IF (eps<=0) THEN	    ! Invalid state
	    UA(1) = 1D10
	    RETURN
      ENDIF

      ! Free energy density
      UA(1) = ( -mu*Jm*LOG(eps)
     &	    - EE*(AINV(5)-AINV(1)*AINV(4)+AINV(2)) )/2
	  ! The energy density should be positive.
      ! Derivatives of the free energy with respect to the invariants
      UI1 = 0
      UI1(1) = (mu/eps + EE*AINV(4))/2
      UI1(2) = -EE/2
      UI1(4) = EE/2*AINV(1)
      UI1(5) = -EE/2
      ! Second order derivatives
      UI2 = 0
      UI2(1) = mu/2/Jm/(eps**2)	! d^2 U / dI1^2
      UI2(7) = EE/2         ! d^2 U / dI1 dI4      

      END SUBROUTINE UANISOHYPER_INV

