C     User-defined subroutine for ideal dielectric elastomer film
C       to be used in Abaqus
C	with Gent's model for the energy of stretching
C =================================================================
C       Material constants:
C           Mechanical - PROPS(1:3): mu, epsilon, Jm
C       Temperature is used as the nominal electric field
C         always applied in the Z-direction before deformation
C -----------------------------------------------------------------
C     4/19/2011, Wei Hong. whong@iastate.edu  All rights reserved
C     2018年6月13日09:41:03       modified by Guoyong Mao rocket-is-coming@163.com
C -----------------------------------------------------------------
      SUBROUTINE UANISOHYPER_INV (AINV, UA, ZETA, NFIBERS, NINV,
     1     UI1, UI2, UI3, TEMP, NOEL, CMNAME, INCMPFLAG, IHYBFLAG,
     2     NUMSTATEV, STATEV, NUMFIELDV, FIELDV, FIELDVINC,
     3     NUMPROPS, PROPS)
C
	     INCLUDE 'ABA_PARAM.INC' 
C
      CHARACTER*80 CMNAME
      DIMENSION AINV(NINV), UA(2), 
     2     ZETA(NFIBERS*(NFIBERS-1)/2), UI1(NINV),
     3     UI2(NINV*(NINV+1)/2), UI3(NINV*(NINV+1)/2),
     4     STATEV(NUMSTATEV), FIELDV(NUMFIELDV),
     5     FIELDVINC(NUMFIELDV), PROPS(NUMPROPS)
      REAL*8 mu,eps,Jm,EE
      PARAMETER(ZERO=0.D0, ONE=1.D0, TWO=2.D0, THREE=3.D0, FOUR=4.D0)
      C10= PROPS(1)         ! parameter 1
      eps= PROPS(2)	    ! perimitivity
	  EE = eps*TEMP**TWO


      UA(1) = ( C10*(AINV(1)-THREE)*TWO
     &	    - EE*(AINV(5)-AINV(1)*AINV(4)+AINV(2)))/TWO
	  ! The energy density should be positive.
      ! Derivatives of the free energy with respect to the invariants
      UI1 = 0
      UI1(1) = C10+EE*AINV(4)/TWO
	  UI1(2) = -EE/TWO
      UI1(4) = EE/TWO*AINV(1)
      UI1(5) = -EE/TWO
      ! Second order derivatives
      UI2 = 0
      UI2(7) = EE/TWO       ! d^2 U / dI1 dI4  
	  UI3=0  

      END SUBROUTINE UANISOHYPER_INV

